@@ -197,13 +197,17 @@ def vv_collisions(T, T1_1, T1_2, idata, molecule1, molecule2, nokt=False):
     dk is the difference between vibrational levels for molecul2)
     An array, which contains the following quantities:
     result[0] - <dE_c ^ 2>_{cd}
-    result[1] - <dE_c * dE_d>_{cd}
-    result[2] - <di * dE_c>_{cd}
-    result[3] - <di * dE_d>_{cd}
-    result[4] - <dE_c>_{cd}
-    result[5] - <di ^ 2>_{cd}
-    result[6] - <di * dk>_{cd}
-    result[7] - <di>_{cd} (should be negligibly small, since, from a theoretical POV, it is precisely equal to 0)
+    result[1] - <dE_d ^ 2>_{cd}
+    result[2] - <dE_c * dE_d>_{cd}
+    result[3] - <di * dE_c>_{cd}
+    result[4] - <di * dE_d>_{cd}
+    result[5] - <dk * dE_c>_{cd}
+    result[6] - <dk * dE_d>_{cd}
+    result[7] - <dE_c>_{cd}
+    result[8] - <dE_d>_{cd}
+    result[9] - <di ^ 2>_{cd}
+    result[10] - <di * dk>_{cd}
+    result[11] - <di>_{cd} (should be negligibly small, since, from a theoretical POV, it is precisely equal to 0)
 
     Takes as input:
 
@@ -217,7 +221,7 @@ def vv_collisions(T, T1_1, T1_2, idata, molecule1, molecule2, nokt=False):
     k - the vibrational level of the second molecule
     nokt - if True, the result is multiplied by (kT) ** (-0.5)
     """
-    tmp_arr = np.zeros(8)
+    result = np.zeros(12)
     Z = molecule1.Z_vibr(T, T1_1) * molecule2.Z_vibr(T, T1_2)
 
     a = np.arange(0, molecule1.num_vibr + 1)
@@ -231,29 +235,38 @@ def vv_collisions(T, T1_1, T1_2, idata, molecule1, molecule2, nokt=False):
     for k in xrange(molecule2.num_vibr):
         for i in xrange(molecule1.num_vibr):
             cs = vv_integral(T, 0, idata, molecule1, molecule2, i, k + 1, 1, nokt)
-            tmp_arr[0] += ((vibr_energy[i] - vibr_energy[i + 1]) ** 2) * vibr_exp[i] * vibr_exp2[k + 1] * cs
-            tmp_arr[1] += ((vibr_energy[i + 1] - vibr_energy[i]) * (vibr_energy2[k] - vibr_energy2[k + 1]))\
+            result[0] += ((vibr_energy[i] - vibr_energy[i + 1]) ** 2) * vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[1] += ((vibr_energy2[k + 1] - vibr_energy2[k]) ** 2) * vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[2] += ((vibr_energy[i + 1] - vibr_energy[i]) * (vibr_energy2[k] - vibr_energy2[k + 1]))\
                 * vibr_exp[i] * vibr_exp2[k + 1] * cs
-            tmp_arr[2] += (vibr_energy[i + 1] - vibr_energy[i]) * vibr_exp[i] * vibr_exp2[k + 1] * cs
-            tmp_arr[3] += (vibr_energy2[k] - vibr_energy2[k + 1]) * vibr_exp[i] * vibr_exp2[k + 1] * cs
-            tmp_arr[4] += (vibr_energy[i + 1] - vibr_energy[i]) * vibr_exp[i] * vibr_exp2[k + 1] * cs
-            tmp_arr[5] += vibr_exp[i] * vibr_exp2[k + 1] * cs  # i, k -> i + 1, k - 1
-            tmp_arr[6] -= vibr_exp[i] * vibr_exp2[k + 1] * cs
-            tmp_arr[7] += vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[3] += (vibr_energy[i + 1] - vibr_energy[i]) * vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[4] += (vibr_energy2[k] - vibr_energy2[k + 1]) * vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[5] -= (vibr_energy[i + 1] - vibr_energy[i]) * vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[6] -= (vibr_energy2[k] - vibr_energy2[k + 1]) * vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[7] += (vibr_energy[i + 1] - vibr_energy[k + 1]) * vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[8] += (vibr_energy2[k] - vibr_energy2[k + 1]) * vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[9] += vibr_exp[i] * vibr_exp2[k + 1] * cs  # i, k -> i + 1, k - 1
+            result[10] -= vibr_exp[i] * vibr_exp2[k + 1] * cs
+            result[11] += vibr_exp[i] * vibr_exp2[k + 1] * cs
 
             cs = vv_integral(T, 0, idata, molecule1, molecule2, i + 1, k, -1, nokt)
-            tmp_arr[0] += ((vibr_energy[i] - vibr_energy[i + 1]) ** 2)\
+            result[0] += ((vibr_energy[i] - vibr_energy[i + 1]) ** 2)\
                 * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <Ev_i^2>
-            tmp_arr[1] += ((vibr_energy[i] - vibr_energy[i + 1]) * (vibr_energy2[k + 1] - vibr_energy2[k]))\
+            result[1] += ((vibr_energy2[k] - vibr_energy2[k + 1]) ** 2)\
+                * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <Ev_k^2>
+            result[2] += ((vibr_energy[i] - vibr_energy[i + 1]) * (vibr_energy2[k + 1] - vibr_energy2[k]))\
                 * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <Ev_i Ev_k>
-            tmp_arr[2] -= (vibr_energy[i] - vibr_energy[i + 1]) * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i * Ev_i>
-            tmp_arr[3] -= (vibr_energy2[k + 1] - vibr_energy2[k]) * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i Ev_k>
-            tmp_arr[4] += (vibr_energy[i] - vibr_energy[i + 1]) * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <Ev_i>
-            tmp_arr[5] += vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i ^ 2>
-            tmp_arr[6] -= vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i k>
-            tmp_arr[7] -= vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i>
+            result[3] -= (vibr_energy[i] - vibr_energy[i + 1]) * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i * Ev_i>
+            result[4] -= (vibr_energy2[k + 1] - vibr_energy2[k]) * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i Ev_k>
+            result[5] += (vibr_energy[i] - vibr_energy[i + 1]) * vibr_exp[i + 1] * vibr_exp2[k] * cs
+            result[6] += (vibr_energy2[k + 1] - vibr_energy2[k]) * vibr_exp[i + 1] * vibr_exp2[k] * cs
+            result[7] += (vibr_energy[i] - vibr_energy[i + 1]) * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <Ev_i>
+            result[8] += (vibr_energy2[k + 1] - vibr_energy2[k]) * vibr_exp[i + 1] * vibr_exp2[k] * cs  # <Ev_k>
+            result[9] += vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i ^ 2>
+            result[10] -= vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i k>
+            result[11] -= vibr_exp[i + 1] * vibr_exp2[k] * cs  # <i>
 
-    return tmp_arr / Z
+    return result / Z
 
 
 def dE_rot_sq(T, molecule):
@@ -294,7 +307,7 @@ def dE_rot_single(T, molecule):
     tmp = integrate.quad(f, 0, molecule.num_rot - 1)[0]
     f = lambda j: (molecule.rot_energy(j, 1) - molecule.rot_energy(j - 1, 1)) * molecule.rot_exp(j, T)
     tmp += integrate.quad(f, 1, molecule.num_rot)[0]
-    tmp *= 1.0 / (molecule.Z_rot(T) * ((constants.k * T))) / molecule.num_rot
+    tmp *= 0.5 / (molecule.Z_rot(T) * ((constants.k * T))) / molecule.num_rot
     return tmp
 
 
@@ -312,4 +325,56 @@ def dE_rot_dE_rot_full(T, molecule1, molecule2):
     molecule1 - the first molecule
     molecule2 - the second molecule2
     """
-    return dE_rot_sq(T, molecule1) + dE_rot_single(T, molecule1) * dE_rot_single(T, molecule2)
\ No newline at end of file
+    return dE_rot_sq(T, molecule1) + dE_rot_single(T, molecule1) * dE_rot_single(T, molecule2)
+
+
+def dE_rot_sq_integral(T, idata, molecule, nokt=False):
+    """Calculates the full averaging of dE_rot^2, where dE_rot is the dimenionless difference between rotational energies
+    Considers all transitions to be one-quantum and equiprobable
+
+    Returns:
+    dE_rot^2, where dE_rot is the dimenionless difference between rotational energies
+
+    Takes as input:
+    T - the temperature of the mixture
+    idata - collision data for the species involved
+    molecule - the molecule
+    nokt - if True, the result is multiplied by (kT) ** (-0.5)
+    """
+    return dE_rot_sq(T, molecule) * elastic_integral(T, 0, idata, nokt=nokt)
+
+
+def dE_rot_single_integral(T, idata, molecule, nokt=False):
+    """Calculates the full averaging of dE_rot, where dE_rot is the dimenionless difference between rotational energies
+    Considers all transitions to be one-quantum and equiprobable
+
+    Returns:
+    dE_rot, where dE_rot is the dimenionless difference between rotational energies
+
+    Takes as input:
+    T - the temperature of the mixture
+    idata - collision data for the species involved
+    molecule - the molecule
+    nokt - if True, the result is multiplied by (kT) ** (-0.5)
+    """
+    return dE_rot_single(T, molecule) * elastic_integral(T, 0, idata, nokt=nokt)
+
+
+def dE_rot_dE_rot_full_integral(T, idata, molecule1, molecule2, nokt=False):
+    """Calculates the full averaging of  dE_rot_c * (dE_rot_c + dE_rot_d), where dE_rot_c is the dimenionless difference
+    between rotational energies for molecule1, and dE_rot_d is the dimenionless difference between rotational energies
+    for molecule2
+    Considers all transitions to be one-quantum and equiprobable
+
+    Returns:
+    dE_rot_c * (dE_rot_c + dE_rot_d), where dE_rot_c is the dimenionless difference between rotational
+    energies for molecule1, and dE_rot_d is the dimenionless difference between rotational energies for molecule2
+
+    Takes as input:
+    T - the temperature of the mixture
+    idata - collision data for the species involved
+    molecule1 - the first molecule
+    molecule2 - the second molecule2
+    nokt - if True, the result is multiplied by (kT) ** (-0.5)
+    """
+    return dE_rot_dE_rot_full(T, molecule1, molecule2) * elastic_integral(T, 0, idata, nokt=nokt)
\ No newline at end of file
