@@ -14,7 +14,7 @@ from scipy.special import gamma
 import crosssection as cs
 
 
-def Zr_original(T, eps, infxi):
+def Zr_original(T, eps, infcoll):
     """
     Calculates the collision amount needed to reach rotational equilibrium for HS model, but has an additional
     addendum
@@ -25,15 +25,15 @@ def Zr_original(T, eps, infxi):
     Takes as input:
     T - the temperature of the mixture
     eps - Lennard-Jones interaction parameter
-    infxi - xi_{\inf} parameter
+    infcoll - zeta_{\inf} parameter
     """
     TTstar = eps / T
     F = 1 + 0.5 * (constants.pi ** 1.5) * (TTstar ** 0.5)\
         + (0.25 * (constants.pi ** 2) + 2) * TTstar + (constants.pi ** 1.5) * (TTstar ** 1.5)
-    return infxi / F
+    return infcoll / F
 
 
-def Zr(T, idata, mass, infxi, model='VSS'):
+def Zr(T, idata, mass, infcoll, model='VSS'):
     """
     Calculates the collision amount needed to reach rotational equilibrium for different models, but has an additional
     addendum
@@ -45,7 +45,7 @@ def Zr(T, idata, mass, infxi, model='VSS'):
     T - the temperature of the mixture
     idata - collision data for the species involved
     mass - mass of molecule undergoing relaxation
-    infxi - xi_{\inf} parameter
+    infcoll - zeta_{\inf} parameter
     model - multiple choice:
         'VSS' - VSS potential
         'VHS' - Variable Hard Sphere potential
@@ -64,10 +64,10 @@ def Zr(T, idata, mass, infxi, model='VSS'):
     TTstar = idata[2] / T
     div = (2.0 - vssomega) / (1.0 + alpha) + 0.5 * (constants.pi ** 1.5) * gamma(1.0 + alpha) * gamma(2.5 - vssomega)\
         * (TTstar ** 0.5) / (gamma(1.5 + alpha) * gamma(2.0 - vssomega)) + (2.0 + 0.25 * (constants.pi ** 2)) * TTstar
-    return mass * infxi / (2.0 * div * idata[0])
+    return mass * infcoll / (2.0 * div * idata[0])
 
 
-def rot_rel_time(T, idata, n, infxi, model='VSS'):
+def rot_rel_time(T, idata, n, infcoll, model='IPL'):
     """
     Calculates the rotational relaxation time using Parker's formula and \Omega^{(2,2)} integral
 
@@ -78,7 +78,7 @@ def rot_rel_time(T, idata, n, infxi, model='VSS'):
     T - the temperature of the mixture
     idata - collision data for the species involved
     n - the numeric density of the mixture
-    infxi - xi_{\inf} parameter
+    infcoll - zeta_{\inf} parameter
     model - model used to calculate the Omega integral:
         'RS' - rigid sphere (then returns result for any l > 0 and r > 0)
         'LJ' - Lennard-Jones (then returns correct result for (l,r) = (1,1) or (l,r) = (2,2), otherwise returns -1)
@@ -87,7 +87,7 @@ def rot_rel_time(T, idata, n, infxi, model='VSS'):
         'Switch' - returns result for LJ model when T / eps < 10 and for IPL model otherwise; eps is the Lennard-Jones
                    parameter
     """
-    return 0.15625 * constants.pi * Zr_original(T, idata[2], infxi) * constants.pi\
+    return 0.15625 * constants.pi * Zr_original(T, idata[2], infcoll) * constants.pi\
         / (n * omega(T, 2, 2, idata, model=model, nokt=False))  # 0.15625 is 5 / 32
 
 
@@ -108,7 +108,7 @@ def rot_tel_time_def(T, idata, molecule, n):
     return 0.25 / (n * cs.elastic_integral(T, 0, idata) * cs.dE_rot_sq(T, molecule))
 
 
-def rot_rel_time_VSS(T, idata, n, mass, infxi, model='VSS'):
+def rot_rel_time_VSS(T, idata, n, mass, infcoll, model='VSS'):
     """ Calculates the rotational relaxation time using the VSS/VHS/HS models and Parker's formula.
 
     Returns:
@@ -119,13 +119,13 @@ def rot_rel_time_VSS(T, idata, n, mass, infxi, model='VSS'):
     idata - collision data for the species involved
     n - the numeric density of the mixture
     mass - the mass of the relaxating molecule
-    infxi - xi_{\inf} parameter
+    infcoll - zeta_{\inf} parameter
     model - multiple choice:
         'VSS' - VSS potential
         'VHS' - Variable Hard Sphere potential
         otherwise - Rigid Sphere model
     """
-    return Zr(T, idata, mass, infxi, model) / ((idata[5] * n
+    return Zr(T, idata, mass, infcoll, model) / ((idata[5] * n
                                                 * ((8 * constants.k * T / (constants.pi * idata[0])) ** 0.5)
                                                 * (T ** -idata[6]) * gamma(2 - idata[6]))
                                                * (constants.physical_constants['Angstrom star'][0] ** 2))
